@@ -589,7 +589,7 @@
    command path may be overridden for a particular system.  For most
    systems, you should just make sure that the programs rmail and
    rnews can be found using this path.  */
-#define CMDPATH "/bin /usr/bin /usr/local/bin"
+#define CMDPATH "/bin /usr/bin /usr/local/bin /usr/sbin"
 
 /* The default amount of free space to require for systems that do not
    specify an amount with the ``free-space'' command.  This is only
